@@ -1,3 +1,4 @@
+import logging
 import pathlib
 
 import click
@@ -9,6 +10,9 @@ from ..config import pass_session
 from ..utils import build_auth_file
 
 
+logger = logging.getLogger("audible_cli.cmds.cmd_manage")
+
+
 @click.group("manage")
 def cli():
     """manage audible-cli"""
@@ -88,7 +92,8 @@ def list_profiles(session):
 def add_profile(ctx, session, profile, country_code, auth_file, is_primary):
     """Adds a profile to config file"""
     if not (session.config.dirname / auth_file).exists():
-        ctx.fail("Auth file doesn't exists.")
+        logger.error("Auth file doesn't exists.")
+        raise click.Abort()
 
     session.config.add_profile(
         name=profile,
@@ -124,7 +129,8 @@ def remove_profile(session, profile):
 def check_if_auth_file_not_exists(session, ctx, param, value):
     value = session.config.dirname / value
     if pathlib.Path(value).exists():
-        ctx.fail("The file already exists.")
+        logger.error("The file already exists.")
+        raise click.Abort()
     return value
 
 
@@ -169,8 +175,10 @@ def check_if_auth_file_not_exists(session, ctx, param, value):
     help="Using a pre-amazon Audible account to login."
 )
 @pass_session
-def add_auth_file(session, auth_file, password, audible_username,
-                  audible_password, country_code, external_login, with_username):
+def add_auth_file(
+        session, auth_file, password, audible_username,
+        audible_password, country_code, external_login, with_username
+):
     """Register a new device and add an auth file to config dir"""
     build_auth_file(
         filename=session.config.dirname / auth_file,
@@ -187,7 +195,8 @@ def add_auth_file(session, auth_file, password, audible_username,
 def check_if_auth_file_exists(session, ctx, param, value):
     value = session.config.dirname / value
     if not pathlib.Path(value).exists():
-        ctx.fail("The file doesn't exists.")
+        logger.error("The file doesn't exists.")
+        raise click.Abort()
     return value
 
 
